/**
 * Copyright(C) 2013 Patrik Dufresne Service Logiciel <info@patrikdufresne.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.planimod.ui.views.admin;

import java.util.HashSet;
import java.util.Set;

import org.eclipse.jface.action.Action;

import com.patrikdufresne.util.Localized;
import com.planimod.ui.databinding.MotifBean;
import com.planimod.ui.theme.Resources;

/**
 * This action is used to add a MotifBean to an PointChart. Notice: this action does not persist the modification.
 * 
 * @author Karl St-Cyr
 * 
 */
public class AddMotifEntry extends Action {

    /**
     * Motif property.
     */
    public static final String MOTIFS = "motifs";//$NON-NLS-1$

    /**
     * Used for localization.
     */
    private Localized localized = Localized.load(AddMotifEntry.class);

    /**
     * The current collection of motifs
     */
    Set<MotifBean> motifs;

    /**
     * Create a new action to add an entry to a motif chart.
     */
    public AddMotifEntry() {
        setText(this.localized.get("AddMotifEntry.text")); //$NON-NLS-1$
        setImageDescriptor(Resources.getImageDescriptor(Resources.ICON_LIST_ADD_16));
        setEnabled(canRun());
        setToolTipText(this.localized.get("AddMotifEntry.tooltip")); //$NON-NLS-1$
    }

    /**
     * Check if this action can be run.
     * 
     * @return True if the action can be run.
     */
    protected boolean canRun() {
        return this.motifs != null;
    }

    /**
     * Returns the set of MotifBean
     * 
     * @return Set<MotifBean>
     */
    public Set<MotifBean> getMotifs() {
        return motifs;
    }

    /**
     * This implementation add a new entry to a MotifBean object
     */
    @Override
    public void run() {
        if (!canRun()) {
            return;
        }
        // Create a new instance of the Motifs
        Set<MotifBean> newMotifs = new HashSet<MotifBean>(this.motifs);
        // Add a new entry
        MotifBean r = new MotifBean();
        r.setName(this.localized.get("AddMotifEntry.newMotif")); //$NON-NLS-1$
        newMotifs.add(r);
        // Fire a property change
        firePropertyChange(MOTIFS, this.motifs, this.motifs = newMotifs);
    }

    /**
     * Sets the point chart object to be updated or null if not set.
     * 
     * @param set
     *            <MotifBean>
     */
    public void setMotifs(Set<MotifBean> motifs) {
        if (this.motifs != motifs) {
            firePropertyChange(MOTIFS, this.motifs, this.motifs = motifs);
            setEnabled(canRun());
        }
    }
}
